import os


def create_project_directory(project_name, path):
    project_path = os.path.join(path, project_name)
    if os.path.isdir(path) and project_name not in os.listdir(path):
        os.mkdir(project_path)

def start_project(path: str, answers: dict) -> None:
    print(f"Path: {path}, Answers: {answers}")
    create_project_directory("uhuu", path)
    # TODO: create settings.py file
    # TODO: create game.py file
    # TODO: create root files: run.py, requirements.txt



import click


@click.group()
def main():
    pass


@click.command()
@click.option(
    "--path",
    "-p",
    help="Absolute path where will be created the projects files.",
    default=".",
    type=str,
)
def startproject(path):
    """Start a new game project."""
    print("Project started!")


main.add_command(startproject)



class Question(dict):
    def __init__(self, type, name, message, choices=None):
        self.type = type
        self.name = name
        self.qmark = "[!]"
        self.message = message
        self.choices = choices or list()

    def __dict__(self):
        return {
            "type": self.type,
            "qmark": self.qmark,
            "message": self.message,
            "name": self.name,
            "choices": list(map(lambda x: {"name": x}, self.choices)),
        }

    def __setitem__(self, key, item):
        self.__dict__()[key] = item

    def __getitem__(self, key):
        return self.__dict__()[key]

    def __iter__(self):
        return iter(self.__dict__())
    
    def __contains__(self, item):
        return item in self.__dict__()
    
    def __len__(self):
        return len(self.__dict__())

    def __delitem__(self, key):
        del self.__dict__()[key]

    def has_key(self, k):
        return k in self.__dict__()

    def update(self, *args, **kwargs):
        return self.__dict__().update(*args, **kwargs)

    def keys(self):
        return self.__dict__().keys()

    def values(self):
        return self.__dict__().values()

    def items(self):
        return self.__dict__().items()

    def pop(self, *args):
        return self.__dict__().pop(*args)
    
    def copy(self):
        return self.__dict__().copy()


class CheckboxQuestion(Question):
    def __init__(self, name, choices=None):
        message = f"Select {name}"
        super().__init__("checkbox", name, message, choices=choices)


class ListQuestion(Question):
    def __init__(self, name, choices=None):
        message = f"Select {name}"
        super().__init__("list", name, message, choices=choices)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cubone',
 'cubone.cli',
 'cubone.modules',
 'cubone.modules.network',
 'cubone.tests']

package_data = \
{'': ['*']}

install_requires = \
['Jinja2>=3.1.2,<4.0.0', 'click>=8.1.3,<9.0.0', 'pygame>=2.1.2,<3.0.0']

entry_points = \
{'console_scripts': ['cubone = cubone.cli.core:main']}

setup_kwargs = {
    'name': 'cubone',
    'version': '0.1.1',
    'description': 'A pygame scaffold package',
    'long_description': None,
    'author': 'Francisco',
    'author_email': 'vieirafrancisco.dev@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
